@@ -2,17 +2,17 @@
 !						SUBROUTINE USED TO COMPUTE THE SGLASSO ESTIMATOR BY THE CCD ALGORITHM (PATH VERSION)
 !
 !	AUTHOR: Luigi Augugliaro
-!	VERSION: 1.0-0
-!	DATA: 23/04/2014
+!	VERSION: 1.2-2
+!	DATA: 01/12/2015
 !
 !	DESCRIPTION: the subroutine sglasso_ccd_path implements the cyclic coordinate descent algorithm proposed
 !						Augugliaro et al., (2014) to fit a weighted l1-norm penalized RCON(V, E) model. 
 !
 !	ARGUMENTS: see arguments in sglasso_ccm_path.f90
 subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_ptr,ne,Te_scn,Te_ptr_scn,nstep,trnc,tol, &
-	rho,nrho,min_rho,grd,th,w,n,conv)
+	rho,nrho,min_rho,grd,th,w,pnl_flg,n,conv)
 	integer	:: nSv,nTv,Tv_pkg(nTv),Tv_rw(nTv),nv,Tv_ptr(nv+1),nTe,Te(nTe),nTe_ptr,Te_ptr(nTe_ptr),ne, &
-		Te_scn(ne+1),Te_ptr_scn(ne+1),nstep,nrho,n,conv
+		Te_scn(ne+1),Te_ptr_scn(ne+1),nstep,nrho,pnl_flg(ne),n,conv
 	double precision	:: Sv(nSv),trnc,tol,rho(nrho),min_rho,grd(nv+ne,nrho),th(nv+ne,nrho),w(ne)
 	!internal variables
 	logical	:: A(ne),flg
@@ -21,13 +21,19 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 	double precision	:: Svh(nSv),tr_SvTv(nv),tr_SvTe(ne),max_rho,Du,oth(nv+ne),ath(nv+ne), &
 		dth,tr_SvhTeSvhTe,tr_SvhTvSvhTv,th_diff,Du_sgn,cf,arho,agrd(nv+ne)
 		
-	A = .false.
+	do i = 1, ne
+   	if (pnl_flg(i).eq.0) then
+			A(i) = .true.
+      else 
+			A(i) = .false.
+		end if
+	end do
 	Svh = 0.
 	ath = 0.
 	oth = 0.
 	agrd = 0.
 	p = Tv_ptr(nv + 1) - 1
-	df = nv
+	df = nv + ne - sum(pnl_flg)
 	max_df = nv + ne
 	
 	k = 0
@@ -63,10 +69,10 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 		call trSTe(nSv,Sv,Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1),tr_SvTe(i))
 		Du = - tr_SvTe(i)
 		agrd(nv + i) = Du
-		max_rho = max(max_rho,abs(Du) / w(i))
+		if(pnl_flg(i).eq.1) max_rho = max(max_rho,abs(Du) / w(i))
 	end do
 
-    if(min_rho.gt.max_rho) return
+	if(min_rho.gt.max_rho) return
 
 	rho(1) = max_rho
 	cf = dexp((dlog(min_rho) - dlog(max_rho)) / (nrho - 1))
@@ -77,9 +83,9 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 	n = 0
 	do nr = 1, nrho
 
-        arho = rho(nr)
+		arho = rho(nr)
 		do i = 1, ne
-			if(.not.A(i)) then
+			if(.not.A(i).and.pnl_flg(i).eq.1) then
 				if(abs(agrd(nv + i))/w(i).gt.arho) then
 					A(i) = .true.
 					df = df + 1
@@ -96,16 +102,16 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 			if(df.gt.nv) then
 				do i = 1, ne
 					if(A(i)) then
-                        n = n + 1
-                        if(n.ge.nstep) then
-                            if(nr.eq.1) then
-                                nrho = nr
-                            else
-                                nrho = nr - 1
-                            end if
-                            conv = 1
-                            return
-                        end if
+               	n = n + 1
+                  if(n.ge.nstep) then
+                  	if(nr.eq.1) then
+                     	nrho = nr
+                     else
+                     	nrho = nr - 1
+                     end if
+                     conv = 1
+                     return
+						end if
 						i0 = Te_scn(i)
 						i1 = Te_scn(i + 1) - 1
 						j0 = Te_ptr_scn(i)
@@ -115,50 +121,52 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 						call trSTe(nSv,Svh,Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1),Du)
 						Du = Du - tr_SvTe(i)
 						agrd(nv + i) = Du
-						Du_sgn = dsign(dble(1),Du)
-						Du = Du - arho * Du_sgn * w(i)
-                        call trSTeSTe(nSv,Svh,Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1), &
-								Te_cl_sz(i),Te_cl(h0:h1),tr_SvhTeSvhTe)
-                        dth = Du / tr_SvhTeSvhTe
-                        if(dth.ne.dth) then
-                            conv = 2
-                            return
-                        end if
-                        ath(nv + i) = ath(nv + i) + dth
-                        call updateSvh_e(p,nSv,Svh,dth,Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1))
-                    end if
-                end do
-            end if
+   	         	if(pnl_flg(i).eq.1) then
+   	            	Du_sgn = dsign(dble(1),Du)
+							Du = Du - arho * Du_sgn * w(i)
+						end if
+						call trSTeSTe(nSv,Svh,Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1), &
+						Te_cl_sz(i),Te_cl(h0:h1),tr_SvhTeSvhTe)
+						dth = Du / tr_SvhTeSvhTe
+						if(dth.ne.dth) then
+							conv = 2
+							return
+						end if
+						ath(nv + i) = ath(nv + i) + dth
+						call updateSvh_e(p,nSv,Svh,dth,Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1))
+					end if
+				end do
+			end if
 
 			do i = 1, nv
-                n = n + 1
-                if(n.ge.nstep) then
-                    if(nr.eq.1) then
-                        nrho = nr
-                    else
-                        nrho = nr - 1
-                    end if
-                    conv = 1
-                    return
-                end if
+				n = n + 1
+				if(n.ge.nstep) then
+					if(nr.eq.1) then
+						nrho = nr
+					else
+						nrho = nr - 1
+					end if
+					conv = 1
+					return
+				end if
 				i0 = Tv_ptr(i)
 				i1 = Tv_ptr(i + 1) - 1
 				Du = sum(Svh(Tv_pkg(i0:i1))) - tr_SvTv(i)
 				agrd(i) = Du
-                tr_SvhTvSvhTv = 0.
-                do h = i0 + 1, i1
-                    do k = i0, h - 1
-                        tr_SvhTvSvhTv = tr_SvhTvSvhTv + Svh(int(Tv_rw(k) + Tv_rw(h) * (Tv_rw(h) - 1) / 2))**2
-                    end do
-                end do
-                tr_SvhTvSvhTv = 2 * tr_SvhTvSvhTv + sum(Svh(Tv_pkg(i0:i1))**2)
-                dth = Du / tr_SvhTvSvhTv
-                if(dth.ne.dth) then
-                    conv = 2
-                    return
-                end if
-                ath(i) = ath(i) + dth
-                call updateSvh_v(p,nSv,Svh,dth,Tv_ptr(i+1)-Tv_ptr(i),Tv_pkg(i0:i1),Tv_rw(i0:i1))
+				tr_SvhTvSvhTv = 0.
+				do h = i0 + 1, i1
+					do k = i0, h - 1
+						tr_SvhTvSvhTv = tr_SvhTvSvhTv + Svh(int(Tv_rw(k) + Tv_rw(h) * (Tv_rw(h) - 1) / 2))**2
+					end do
+				end do
+				tr_SvhTvSvhTv = 2 * tr_SvhTvSvhTv + sum(Svh(Tv_pkg(i0:i1))**2)
+				dth = Du / tr_SvhTvSvhTv
+				if(dth.ne.dth) then
+					conv = 2
+					return
+				end if
+				ath(i) = ath(i) + dth
+				call updateSvh_v(p,nSv,Svh,dth,Tv_ptr(i+1)-Tv_ptr(i),Tv_pkg(i0:i1),Tv_rw(i0:i1))
 			end do
 
 			th_diff = sum(abs(ath(1:nv) - oth(1:nv)))
@@ -172,17 +180,17 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 
 			if(th_diff/df.lt.tol) then
 				flg = .true.
-                do i = 1, ne
-                    if(A(i).and.abs(ath(nv + i)).gt.trnc) then
-                        if((ath(nv + i) * agrd(nv + i)).lt.0.) then
-                            flg = .false.
-                            call updateSvh_e(p,nSv,Svh,-ath(nv + i),Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1))
-                            ath(nv + i) = 0.
-                            A(i) = .false.
-                            df = df - 1
-                        end if
-                    end if
-                end do
+				do i = 1, ne
+					if(A(i).and.abs(ath(nv + i)).gt.trnc.and.pnl_flg(i).eq.1) then
+						if((ath(nv + i) * agrd(nv + i)).lt.0.) then
+							flg = .false.
+							call updateSvh_e(p,nSv,Svh,-ath(nv + i),Te_scn_sz(i),Te(i0:i1),Tv_ptr(nv+1),Te_ptr(j0:j1))
+							ath(nv + i) = 0.
+							A(i) = .false.
+							df = df - 1
+						end if
+					end if
+				end do
 				if(flg) then
 					do i = 1, ne
 						if(.not.A(i)) then
@@ -191,7 +199,7 @@ subroutine sglasso_ccd_path(nSv,Sv,nTv,Tv_pkg,Tv_rw,nv,Tv_ptr,nTe,Te,nTe_ptr,Te_
 							Du = Du - tr_SvTe(i)
 							agrd(nv + i) = Du
 							if(abs(Du)/w(i) - arho .gt. 0.) then
-                                flg = .false.
+								flg = .false.
 								A(i) = .true.
 								df = df + 1
 							end if
